==> mn-api-0.1.2.tar.gz: mn-api-0.1.2/README.md <==
# MN Api

![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)
![Pipy](https://img.shields.io/badge/pypi-3775A9?style=for-the-badge&logo=pypi&logoColor=white)
![Numpy](https://img.shields.io/badge/Numpy-777BB4?style=for-the-badge&logo=numpy&logoColor=white)
![SciPy](https://img.shields.io/badge/SciPy-%230C55A5.svg?style=for-the-badge&logo=scipy&logoColor=%white)
![Pandas](https://img.shields.io/badge/pandas-%23150458.svg?style=for-the-badge&logo=pandas&logoColor=white)
![GitHub Actions](https://img.shields.io/badge/github%20actions-%232671E5.svg?style=for-the-badge&logo=githubactions&logoColor=white)
![example workflow](https://github.com/EduardoProfe666/mn-api/actions/workflows/pypy.yml/badge.svg)

> [!WARNING]
> El paquete aún se encuentra en desarrollo por lo que pueden existir errores

El paquete es una migración de todas las funcionalidades
desarrolladas en el proyecto
de [Matemática Numérica](https://github.com/EduardoProfe666/Matematica-Numerica-Google-Colab/).

Contiene implementaciones de los principales métodos numéricos dados
en Matemática Numérica.

## ⚙️ Estructura y Funcionalidades

La siguiente lista proporciona la estructura y principales
funcionalidades de la api:

- [x] _**Capítulo 1: Teoría de Errores**_
  - [x] **Cifras**
      - Cifras decimales
      - Cifras significativs
      - Cifras exactas
  - [x] **Medidas del Error**
      - Error
      - Error absoluto
      - Error relativo
      - Mínimo error absoluto máximo
- [x] _**Capítulo 2: Raíces de Ecuaciones Algebraicas**_
  - [x] **Separación de Raíces**
      - Bolzano-Cauchy
      - Descartes
      - Lagrange
      - Método Gráfico
  - [x] **Resolución de ecuaciones algebraicas**
      - Bisección
      - Newton-Raphson
      - Regula-Falsi
      - Secantes
- [x] _**Capítulo 3: Sistemas de Ecuaciones Lineales y Matrices**_
  - [x] **Métodos** 
    - Método de Jacobi
    - Método de Gauss-Seidel
  - [x] **Utilidades**
    - Conversión de matrices AX=B -> X=MX+C
    - Matriz con diagonal predominante
    - Factor de convergencia
- [ ] _**Capítulo 4: Aproximación de Funciones**_
- [ ] _**Capítulo 5: Integración Numérica**_
- [ ] _**Capítulo 6: Optimización Numérica**_
- [ ] _**Capítulo 7: Ecuaciones Diferenciales Ordinarias**_

## 📄 Importación y documentación

> [!IMPORTANT]
> La documentación se encuentra en desarrollo. Pronto estará disponible

Para poder importar el paquete ejecute en cualquier consola:

```shell
pip install mn-api
```

La documentación de la api se encuentra disponible [aquí](https://github.com/EduardoProfe666/mn-api-docs)

==> mn-api-0.6.1.tar.gz: mn-api-0.6.1/README.md <==
# MN Api

![Python](https://img.shields.io/badge/python-3670A0?style=for-the-badge&logo=python&logoColor=ffdd54)
![Pipy](https://img.shields.io/badge/pypi-3775A9?style=for-the-badge&logo=pypi&logoColor=white)
![Numpy](https://img.shields.io/badge/Numpy-777BB4?style=for-the-badge&logo=numpy&logoColor=white)
![SciPy](https://img.shields.io/badge/SciPy-%230C55A5.svg?style=for-the-badge&logo=scipy&logoColor=%white)
![Pandas](https://img.shields.io/badge/pandas-%23150458.svg?style=for-the-badge&logo=pandas&logoColor=white)
![GitHub Actions](https://img.shields.io/badge/github%20actions-%232671E5.svg?style=for-the-badge&logo=githubactions&logoColor=white)
![example workflow](https://github.com/EduardoProfe666/mn-api/actions/workflows/pypy.yml/badge.svg)

> [!WARNING]
> El paquete aún se encuentra en desarrollo por lo que pueden existir errores

El paquete es una migración de todas las funcionalidades
desarrolladas en el proyecto
de [Matemática Numérica](https://github.com/EduardoProfe666/Matematica-Numerica-Google-Colab/).

Contiene implementaciones de los principales métodos numéricos dados
en Matemática Numérica.

## ⚙️ Estructura y Funcionalidades

La siguiente lista proporciona la estructura y principales
funcionalidades de la api:

- [x] _**Capítulo 1: Teoría de Errores**_
  - [x] **Cifras**
      - Cifras decimales
      - Cifras significativs
      - Cifras exactas
  - [x] **Medidas del Error**
      - Error
      - Error absoluto
      - Error relativo
      - Mínimo error absoluto máximo
- [x] _**Capítulo 2: Raíces de Ecuaciones Algebraicas**_
  - [x] **Separación de Raíces**
      - Bolzano-Cauchy
      - Descartes
      - Lagrange
      - Método Gráfico
  - [x] **Resolución de ecuaciones algebraicas**
      - Bisección
      - Newton-Raphson
      - Regula-Falsi
      - Secantes
- [x] _**Capítulo 3: Sistemas de Ecuaciones Lineales y Matrices**_
  - [x] **Métodos** 
    - Método de Jacobi
    - Método de Gauss-Seidel
  - [x] **Utilidades**
    - Conversión de matrices AX=B -> X=MX+C
    - Matriz con diagonal predominante
    - Factor de convergencia
- [x] _**Capítulo 4: Aproximación de Funciones**_
  - [x] **Métodos**
    - Método de Lagrange
    - Método de Newton o Diferencias Divididas
- [ ] _**Capítulo 5: Integración Numérica**_
- [ ] _**Capítulo 6: Optimización Numérica**_
- [ ] _**Capítulo 7: Ecuaciones Diferenciales Ordinarias**_

## 📄 Importación y documentación

> [!IMPORTANT]
> La documentación se encuentra en desarrollo. Pronto estará disponible

Para poder importar el paquete, ejecute en cualquier consola:

```shell
pip install mn-api
```

La documentación de la api se encuentra disponible [aquí](https://github.com/EduardoProfe666/mn-api-docs)
